<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Words fix</source>
        <translation>Korekta słów</translation>
    </message>
    <message>
        <source>Enable word fix</source>
        <translation>Włącz korektę słów</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Sprawdzanie pisowni</translation>
    </message>
</context>
<context>
    <name>WordFixConfigurationUiHandler</name>
    <message>
        <source>A word to be replaced</source>
        <translation>Słowo do zamiany</translation>
    </message>
    <message>
        <source>Value to replace with</source>
        <translation>Zmienione słowo</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Zmień</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Word</source>
        <translation>Słowo</translation>
    </message>
    <message>
        <source>Replace with</source>
        <translation>Zamień na</translation>
    </message>
</context>
</TS>